@@ -1,11 +1,11 @@
 // Copyright (C) 2022 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
+#include <QtCore/qglobal.h>
+
 #ifndef QTDATAVISUALIZATIONEXPORTS_H
 #define QTDATAVISUALIZATIONEXPORTS_H
 
-#include <QtCore/qglobal.h>
-
 #if defined(QT_SHARED) || !defined(QT_STATIC)
 #  if defined(QT_BUILD_DATAVISUALIZATION_LIB)
 #    define Q_DATAVISUALIZATION_EXPORT Q_DECL_EXPORT
@@ -16,8 +16,9 @@
 #  define Q_DATAVISUALIZATION_EXPORT
 #endif
 
-#if !defined(QT_BUILD_DATAVISUALIZATION_LIB) || defined(QT_STATIC)
+#if !defined(QT_BUILD_DATAVISUALIZATION_LIB) && !defined(QT_STATIC)
 /* outside library → inline decl + defi */
+/* static builds treat everything as part of the library, so they never inline */
 #  define QT_DATAVISUALIZATION_INLINE_SINCE(major, minor) inline
 #  define QT_DATAVISUALIZATION_INLINE_IMPL_SINCE(major, minor) 1
 #elif defined(QT_DATAVISUALIZATION_BUILD_REMOVED_API)
